#statistics

**Support Vector Machines** is a statistical classification algorithm that provides binary classification through a hyperplane that maximises the margin of separation.

The _support vectors_ are the data points closest to the hyperplane, which have the highest influence on its position.

SVM forces the data to be linearly separable by re-projecting it onto a higher-dimension space until linear separability through a hyperplane is achievable.